pub struct GetActivityTaskInput {
pub activity_arn: String,
pub worker_name: Option<String>,
}Fields
activity_arn: StringThe Amazon Resource Name (ARN) of the activity to retrieve tasks from (assigned when you create the task using CreateActivity.)
worker_name: Option<String>You can provide an arbitrary name in order to identify the worker that the task is assigned to. This name is used when it is logged in the execution history.